@@ -5,7 +5,7 @@ use vars qw($VERSION @EXPORT_OK);
 use Exporter;
 use base qw(Exporter);
 
-$VERSION = '0.2';
+$VERSION = '0.3';
 
 @EXPORT_OK = qw(NOKEYS NOCERTS INFO CLCERTS CACERTS);
 
@@ -47,15 +47,63 @@ Crypt::OpenSSL::PKCS12 - Perl extension to OpenSSL's PKCS12 API.
 
 =head1 DESCRIPTION
 
-  This implement a small bit of OpenSSL's PKCS12 API.
+  This implements a small bit of OpenSSL's PKCS12 API.
 
-=head2 EXPORT
+=head1 FUNCTIONS
+
+=over 4
+
+=item * new( )
+
+=item * new_from_string( $string )
+
+=item * new_from_file( $filename )
+
+Create a new Crypt::OpenSSL::PKCS12 instance.
+
+=item * certificate( [$pass] )
+
+Get the Base64 representation of the certificate.
+
+=item * as_string( [$pass] )
+
+Get the binary represenation as a string.
+
+=item * mac_ok( [$pass] )
+
+Verifiy the certificates Message Authentication Code
+
+=item * changepass( $old, $new )
+
+Change a certificate's password.
+
+=item * create( $cert, $key, $pass, $output_file, $friendly_name )
+
+Create a new PKCS12 certificate. $cert & $key may either be strings or filenames.
+
+$friendly_name is optional.
+
+=back
+
+=head1 EXPORT
 
 None by default.
 
 On request:
 
-	NOKEYS NOCERTS INFO CLCERTS CACERTS
+=over 4
+
+=item * NOKEYS
+
+=item * NOCERTS
+
+=item * INFO
+
+=item * CLCERTS
+
+=item * CACERTS
+
+=back
 
 =head1 SEE ALSO
 
@@ -70,6 +118,7 @@ Dan Sully, E<lt>daniel@cpan.orgE<gt>
 Copyright 2004-2007 by Dan Sully
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself. 
+it under the same terms as Perl itself, either Perl version 5.8.8 or,
+at your option, any later version of Perl 5 you may have available.
 
 =cut
